ResultTracker
=============

.. currentmodule:: pykeen.trackers

.. autoclass:: ResultTracker
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ResultTracker.end_run
      ~ResultTracker.log_metrics
      ~ResultTracker.log_params
      ~ResultTracker.start_run

   .. rubric:: Methods Documentation

   .. automethod:: end_run
   .. automethod:: log_metrics
   .. automethod:: log_params
   .. automethod:: start_run
